Skip to contents

Calculate target cell counts per type based on total positions and cell type fractions.

Usage

get_target_counts(total_cells, fractions)

Arguments

total_cells

Total number of cells to assign.

fractions

Named vector of cell type fractions (should sum to 1).

Value

Named integer vector of target counts per cell type.